# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: rekor/v2/dsse.proto, rekor/v2/entry.proto, rekor/v2/hashedrekord.proto, rekor/v2/verifier.proto
# plugin: python-betterproto
# This file has been @generated

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from dataclasses import dataclass
else:
    from pydantic.dataclasses import dataclass

from typing import (
    List,
    Optional,
)

import betterproto
from pydantic import model_validator
from pydantic.dataclasses import rebuild_dataclass

from .....io import intoto as ____io_intoto__
from ...common import v1 as __common_v1__


@dataclass(eq=False, repr=False)
class PublicKey(betterproto.Message):
    """PublicKey contains an encoded public key"""

    raw_bytes: bytes = betterproto.bytes_field(1)
    """DER-encoded public key"""


@dataclass(eq=False, repr=False)
class Verifier(betterproto.Message):
    """
    Either a public key or a X.509 cerificiate with an embedded public key
    """

    public_key: Optional["PublicKey"] = betterproto.message_field(
        1, optional=True, group="verifier"
    )
    """
    DER-encoded public key. Encoding method is specified by the key_details attribute
    """

    x509_certificate: Optional["__common_v1__.X509Certificate"] = (
        betterproto.message_field(2, optional=True, group="verifier")
    )
    """DER-encoded certificate"""

    key_details: "__common_v1__.PublicKeyDetails" = betterproto.enum_field(3)
    """Key encoding and signature algorithm to use for this key"""

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


@dataclass(eq=False, repr=False)
class Signature(betterproto.Message):
    """A signature and an associated verifier"""

    content: bytes = betterproto.bytes_field(1)
    verifier: "Verifier" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class DsseRequestV002(betterproto.Message):
    """A request to add a DSSE v0.0.2 entry to the log"""

    envelope: "____io_intoto__.Envelope" = betterproto.message_field(1)
    """A DSSE envelope"""

    verifiers: List["Verifier"] = betterproto.message_field(2)
    """
    All necessary verification material to verify all signatures embedded in the envelope
    """


@dataclass(eq=False, repr=False)
class DsseLogEntryV002(betterproto.Message):
    payload_hash: "__common_v1__.HashOutput" = betterproto.message_field(1)
    """The hash of the DSSE payload"""

    signatures: List["Signature"] = betterproto.message_field(2)
    """
    Signatures and their associated verification material used to verify the payload
    """


@dataclass(eq=False, repr=False)
class HashedRekordRequestV002(betterproto.Message):
    """A request to add a hashedrekord v0.0.2 to the log"""

    digest: bytes = betterproto.bytes_field(1)
    """The hashed data"""

    signature: "Signature" = betterproto.message_field(2)
    """
    A single signature over the hashed data with the verifier needed to validate it
    """


@dataclass(eq=False, repr=False)
class HashedRekordLogEntryV002(betterproto.Message):
    data: "__common_v1__.HashOutput" = betterproto.message_field(1)
    """The hashed data"""

    signature: "Signature" = betterproto.message_field(2)
    """
    A single signature over the hashed data with the verifier needed to validate it
    """


@dataclass(eq=False, repr=False)
class Entry(betterproto.Message):
    """
    Entry is the message that is canonicalized and uploaded to the log.
     This format is meant to be compliant with Rekor v1 entries in that
     the `apiVersion` and `kind` can be parsed before parsing the spec.
     Clients are expected to understand and handle the differences in the
     contents of `spec` between Rekor v1 (a polymorphic OpenAPI defintion)
     and Rekor v2 (a typed proto defintion).
    """

    kind: str = betterproto.string_field(1)
    api_version: str = betterproto.string_field(2)
    spec: "Spec" = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class Spec(betterproto.Message):
    """Spec contains one of the Rekor entry types."""

    hashed_rekord_v002: Optional["HashedRekordLogEntryV002"] = (
        betterproto.message_field(1, optional=True, group="spec")
    )
    dsse_v002: Optional["DsseLogEntryV002"] = betterproto.message_field(
        2, optional=True, group="spec"
    )

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


@dataclass(eq=False, repr=False)
class CreateEntryRequest(betterproto.Message):
    """Create a new HashedRekord or DSSE"""

    hashed_rekord_request_v002: Optional["HashedRekordRequestV002"] = (
        betterproto.message_field(1, optional=True, group="spec")
    )
    dsse_request_v002: Optional["DsseRequestV002"] = betterproto.message_field(
        2, optional=True, group="spec"
    )

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


rebuild_dataclass(Verifier)  # type: ignore
rebuild_dataclass(Signature)  # type: ignore
rebuild_dataclass(DsseRequestV002)  # type: ignore
rebuild_dataclass(DsseLogEntryV002)  # type: ignore
rebuild_dataclass(HashedRekordRequestV002)  # type: ignore
rebuild_dataclass(HashedRekordLogEntryV002)  # type: ignore
rebuild_dataclass(Entry)  # type: ignore
rebuild_dataclass(Spec)  # type: ignore
rebuild_dataclass(CreateEntryRequest)  # type: ignore



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: in_toto_attestation/predicates/vulns/v0.2/vulns.proto
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n5in_toto_attestation/predicates/vulns/v0.2/vulns.proto\x12(in_toto_attestation.predicates.vulns.v02\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x95\x01\n\x05Vulns\x12\x42\n\x07scanner\x18\x01 \x01(\x0b\x32\x31.in_toto_attestation.predicates.vulns.v02.Scanner\x12H\n\x08metadata\x18\x02 \x01(\x0b\x32\x36.in_toto_attestation.predicates.vulns.v02.ScanMetadata"\xbe\x01\n\x07Scanner\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x14\n\x07version\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x02\x64\x62\x18\x03 \x01(\x0b\x32\x36.in_toto_attestation.predicates.vulns.v02.VulnDatabase\x12@\n\x06result\x18\x04 \x03(\x0b\x32\x30.in_toto_attestation.predicates.vulns.v02.ResultB\n\n\x08_version"{\n\x0cVulnDatabase\x12\x10\n\x03uri\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\tH\x01\x88\x01\x01\x12/\n\x0blast_update\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\n\x04_uriB\n\n\x08_version"\xba\x01\n\x06Result\x12\n\n\x02id\x18\x01 \x01(\t\x12K\n\x08severity\x18\x02 \x03(\x0b\x32\x39.in_toto_attestation.predicates.vulns.v02.Result.Severity\x12,\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x1a)\n\x08Severity\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\t"y\n\x0cScanMetadata\x12\x33\n\x0fscan_started_on\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10scan_finished_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBk\n1io.github.intoto.attestation.predicates.vulns.v02Z6github.com/in-toto/attestation/go/predicates/vulns/v02b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "in_toto_attestation.predicates.vulns.v0.2.vulns_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n1io.github.intoto.attestation.predicates.vulns.v02Z6github.com/in-toto/attestation/go/predicates/vulns/v02"
    _globals["_VULNS"]._serialized_start = 163
    _globals["_VULNS"]._serialized_end = 312
    _globals["_SCANNER"]._serialized_start = 315
    _globals["_SCANNER"]._serialized_end = 505
    _globals["_VULNDATABASE"]._serialized_start = 507
    _globals["_VULNDATABASE"]._serialized_end = 630
    _globals["_RESULT"]._serialized_start = 633
    _globals["_RESULT"]._serialized_end = 819
    _globals["_RESULT_SEVERITY"]._serialized_start = 778
    _globals["_RESULT_SEVERITY"]._serialized_end = 819
    _globals["_SCANMETADATA"]._serialized_start = 821
    _globals["_SCANMETADATA"]._serialized_end = 942
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: in_toto_attestation/predicates/vsa/v0/vsa.proto
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/in_toto_attestation/predicates/vsa/v0/vsa.proto\x12%in_toto_attestation.predicates.vsa.v0\x1a\x1fgoogle/protobuf/timestamp.proto"\xa9\x08\n\x13VerificationSummary\x12U\n\x08verifier\x18\x01 \x01(\x0b\x32\x43.in_toto_attestation.predicates.vsa.v0.VerificationSummary.Verifier\x12@\n\rtime_verified\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rtime_verified\x12"\n\x0cresource_uri\x18\x03 \x01(\tR\x0cresource_uri\x12Q\n\x06policy\x18\x04 \x01(\x0b\x32\x41.in_toto_attestation.predicates.vsa.v0.VerificationSummary.Policy\x12{\n\x12input_attestations\x18\x05 \x03(\x0b\x32K.in_toto_attestation.predicates.vsa.v0.VerificationSummary.InputAttestationR\x12input_attestations\x12\x30\n\x13verification_result\x18\x06 \x01(\tR\x13verification_result\x12"\n\x0cpolicy_level\x18\x07 \x01(\tR\x0cpolicy_level\x12~\n\x11\x64\x65pendency_levels\x18\x08 \x03(\x0b\x32P.in_toto_attestation.predicates.vsa.v0.VerificationSummary.DependencyLevelsEntryR\x11\x64\x65pendency_levels\x1a\x16\n\x08Verifier\x12\n\n\x02id\x18\x01 \x01(\t\x1a\xa3\x01\n\x06Policy\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12]\n\x06\x64igest\x18\x02 \x03(\x0b\x32M.in_toto_attestation.predicates.vsa.v0.VerificationSummary.Policy.DigestEntry\x1a-\n\x0b\x44igestEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xb7\x01\n\x10InputAttestation\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12g\n\x06\x64igest\x18\x02 \x03(\x0b\x32W.in_toto_attestation.predicates.vsa.v0.VerificationSummary.InputAttestation.DigestEntry\x1a-\n\x0b\x44igestEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15\x44\x65pendencyLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x42\x65\n.io.github.intoto.attestation.predicates.vsa.v0Z3github.com/in-toto/attestation/go/predicates/vsa/v0b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "in_toto_attestation.predicates.vsa.v0.vsa_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n.io.github.intoto.attestation.predicates.vsa.v0Z3github.com/in-toto/attestation/go/predicates/vsa/v0"
    _globals["_VERIFICATIONSUMMARY_POLICY_DIGESTENTRY"]._options = None
    _globals["_VERIFICATIONSUMMARY_POLICY_DIGESTENTRY"]._serialized_options = b"8\001"
    _globals["_VERIFICATIONSUMMARY_INPUTATTESTATION_DIGESTENTRY"]._options = None
    _globals[
        "_VERIFICATIONSUMMARY_INPUTATTESTATION_DIGESTENTRY"
    ]._serialized_options = b"8\001"
    _globals["_VERIFICATIONSUMMARY_DEPENDENCYLEVELSENTRY"]._options = None
    _globals[
        "_VERIFICATIONSUMMARY_DEPENDENCYLEVELSENTRY"
    ]._serialized_options = b"8\001"
    _globals["_VERIFICATIONSUMMARY"]._serialized_start = 124
    _globals["_VERIFICATIONSUMMARY"]._serialized_end = 1189
    _globals["_VERIFICATIONSUMMARY_VERIFIER"]._serialized_start = 758
    _globals["_VERIFICATIONSUMMARY_VERIFIER"]._serialized_end = 780
    _globals["_VERIFICATIONSUMMARY_POLICY"]._serialized_start = 783
    _globals["_VERIFICATIONSUMMARY_POLICY"]._serialized_end = 946
    _globals["_VERIFICATIONSUMMARY_POLICY_DIGESTENTRY"]._serialized_start = 901
    _globals["_VERIFICATIONSUMMARY_POLICY_DIGESTENTRY"]._serialized_end = 946
    _globals["_VERIFICATIONSUMMARY_INPUTATTESTATION"]._serialized_start = 949
    _globals["_VERIFICATIONSUMMARY_INPUTATTESTATION"]._serialized_end = 1132
    _globals[
        "_VERIFICATIONSUMMARY_INPUTATTESTATION_DIGESTENTRY"
    ]._serialized_start = 901
    _globals["_VERIFICATIONSUMMARY_INPUTATTESTATION_DIGESTENTRY"]._serialized_end = 946
    _globals["_VERIFICATIONSUMMARY_DEPENDENCYLEVELSENTRY"]._serialized_start = 1134
    _globals["_VERIFICATIONSUMMARY_DEPENDENCYLEVELSENTRY"]._serialized_end = 1189
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: in_toto_attestation/predicates/release/v0/release.proto
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n7in_toto_attestation/predicates/release/v0/release.proto\x12)in_toto_attestation.predicates.release.v0"?\n\x07Release\x12\x0c\n\x04purl\x18\x01 \x01(\t\x12\x17\n\nrelease_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_release_idBm\n2io.github.intoto.attestation.predicates.release.v0Z7github.com/in-toto/attestation/go/predicates/release/v0b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "in_toto_attestation.predicates.release.v0.release_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n2io.github.intoto.attestation.predicates.release.v0Z7github.com/in-toto/attestation/go/predicates/release/v0"
    _globals["_RELEASE"]._serialized_start = 102
    _globals["_RELEASE"]._serialized_end = 165
# @@protoc_insertion_point(module_scope)
